* [U-Boot] [PATCH v2 08/35] zynq: Add GEM0, GEM1 configs support
From: Jagannadha Sutradharudu Teki @ 2013-12-18 15:29 UTC (permalink / raw)
To: u-boot
In-Reply-To: <1387380620-29228-1-git-send-email-jaganna@xilinx.com>
Zynq ethernet controller support two GEM's like
CONFIG_ZYNQ_GEM0 and CONFIG_ZYNQ_GEM1 enabled
both so-that the respective board will define
these macros based on their usage.
Signed-off-by: Jagannadha Sutradharudu Teki <jaganna@xilinx.com>
---
V2: none
include/configs/zynq.h | 16 ++++++++--------
1 file changed, 8 insertions(+), 8 deletions(-)
diff --git a/include/configs/zynq.h b/include/configs/zynq.h
index f104558..ea25159 100644
--- a/include/configs/zynq.h
+++ b/include/configs/zynq.h
@@ -57,10 +57,16 @@
#endif
/* Ethernet driver */
-#define CONFIG_NET_MULTI
-#define CONFIG_ZYNQ_GEM
#define CONFIG_ZYNQ_GEM0
#define CONFIG_ZYNQ_GEM_PHY_ADDR0 7
+#if defined(CONFIG_ZYNQ_GEM0) || defined(CONFIG_ZYNQ_GEM1)
+# define CONFIG_NET_MULTI
+# define CONFIG_ZYNQ_GEM
+# define CONFIG_MII
+# define CONFIG_SYS_FAULT_ECHO_LINK_DOWN
+# define CONFIG_PHYLIB
+# define CONFIG_PHY_MARVELL
+#endif
#define CONFIG_ZYNQ_SPI
/* SPI */
@@ -103,12 +109,6 @@
#define CONFIG_BOOTP_HOSTNAME
#define CONFIG_BOOTP_MAY_FAIL
-/* MII and Phylib */
-#define CONFIG_MII
-#define CONFIG_SYS_FAULT_ECHO_LINK_DOWN
-#define CONFIG_PHYLIB
-#define CONFIG_PHY_MARVELL
-
/* Environment */
#define CONFIG_ENV_SIZE 0x10000 /* Env. sector size */
#define CONFIG_ENV_IS_NOWHERE
--
1.8.3
^ permalink raw reply related
* [U-Boot] [PATCH v2 07/35] zynq: Add UART0, UART1 configs support
From: Jagannadha Sutradharudu Teki @ 2013-12-18 15:29 UTC (permalink / raw)
To: u-boot
In-Reply-To: <1387380620-29228-1-git-send-email-jaganna@xilinx.com>
Zynq uart controller support two serial ports like
CONFIG_ZYNQ_SERIAL_UART0 and CONFIG_ZYNQ_SERIAL_UART1
enabled both so-that the respective board will define
these macros based on their usage.
Signed-off-by: Jagannadha Sutradharudu Teki <jaganna@xilinx.com>
---
V2: none
include/configs/zynq.h | 20 ++++++++++++++++----
1 file changed, 16 insertions(+), 4 deletions(-)
diff --git a/include/configs/zynq.h b/include/configs/zynq.h
index 6e545e5..f104558 100644
--- a/include/configs/zynq.h
+++ b/include/configs/zynq.h
@@ -33,10 +33,22 @@
{300, 600, 1200, 2400, 4800, 9600, 19200, 38400, 57600, 115200, 230400}
/* Zynq Serial driver */
-#define CONFIG_ZYNQ_SERIAL
-#define CONFIG_ZYNQ_SERIAL_BASEADDR0 0xE0001000
-#define CONFIG_ZYNQ_SERIAL_BAUDRATE0 CONFIG_BAUDRATE
-#define CONFIG_ZYNQ_SERIAL_CLOCK0 50000000
+#define CONFIG_ZYNQ_SERIAL_UART1
+#ifdef CONFIG_ZYNQ_SERIAL_UART0
+# define CONFIG_ZYNQ_SERIAL_BASEADDR0 0xE0000000
+# define CONFIG_ZYNQ_SERIAL_BAUDRATE0 CONFIG_BAUDRATE
+# define CONFIG_ZYNQ_SERIAL_CLOCK0 50000000
+#endif
+
+#ifdef CONFIG_ZYNQ_SERIAL_UART1
+# define CONFIG_ZYNQ_SERIAL_BASEADDR1 0xE0001000
+# define CONFIG_ZYNQ_SERIAL_BAUDRATE1 CONFIG_BAUDRATE
+# define CONFIG_ZYNQ_SERIAL_CLOCK1 50000000
+#endif
+
+#if defined(CONFIG_ZYNQ_SERIAL_UART0) || defined(CONFIG_ZYNQ_SERIAL_UART1)
+# define CONFIG_ZYNQ_SERIAL
+#endif
/* DCC driver */
#if defined(CONFIG_ZYNQ_DCC)
--
1.8.3
^ permalink raw reply related
* [U-Boot] [PATCH v2 06/35] zynq: Enable cache options
From: Jagannadha Sutradharudu Teki @ 2013-12-18 15:29 UTC (permalink / raw)
To: u-boot
In-Reply-To: <1387380620-29228-1-git-send-email-jaganna@xilinx.com>
- Enable cache command
- Turn-off L2 cache
- Turn-on D-cache
Signed-off-by: Jagannadha Sutradharudu Teki <jaganna@xilinx.com>
---
V2: none
include/configs/zynq.h | 10 ++++++++++
1 file changed, 10 insertions(+)
diff --git a/include/configs/zynq.h b/include/configs/zynq.h
index c8ab06f..6e545e5 100644
--- a/include/configs/zynq.h
+++ b/include/configs/zynq.h
@@ -16,6 +16,16 @@
# define CONFIG_CPU_FREQ_HZ 800000000
#endif
+/* Cache options */
+#define CONFIG_CMD_CACHE
+#define CONFIG_SYS_CACHELINE_SIZE 32
+
+#define CONFIG_SYS_L2CACHE_OFF
+#ifndef CONFIG_SYS_L2CACHE_OFF
+# define CONFIG_SYS_L2_PL310
+# define CONFIG_SYS_PL310_BASE 0xf8f02000
+#endif
+
/* Serial drivers */
#define CONFIG_BAUDRATE 115200
/* The following table includes the supported baudrates */
--
1.8.3
^ permalink raw reply related
* [U-Boot] [PATCH v2 05/35] zynq: Minor config cleanup
From: Jagannadha Sutradharudu Teki @ 2013-12-18 15:29 UTC (permalink / raw)
To: u-boot
In-Reply-To: <1387380620-29228-1-git-send-email-jaganna@xilinx.com>
Cleanups mostly on:
- Add comments
- Re-order configs
- Remove #define CONFIG_ZYNQ_SDHCI
Signed-off-by: Jagannadha Sutradharudu Teki <jaganna@xilinx.com>
---
V2: none
include/configs/zynq.h | 76 ++++++++++++++++++++++++++------------------------
1 file changed, 39 insertions(+), 37 deletions(-)
diff --git a/include/configs/zynq.h b/include/configs/zynq.h
index 8be52df..c8ab06f 100644
--- a/include/configs/zynq.h
+++ b/include/configs/zynq.h
@@ -7,33 +7,51 @@
#ifndef __CONFIG_ZYNQ_H
#define __CONFIG_ZYNQ_H
-#define CONFIG_ARMV7 /* This is an ARM V7 CPU core */
+/* High Level configuration Options */
+#define CONFIG_ARMV7
#define CONFIG_ZYNQ
/* CPU clock */
-#define CONFIG_CPU_FREQ_HZ 800000000
+#ifndef CONFIG_CPU_FREQ_HZ
+# define CONFIG_CPU_FREQ_HZ 800000000
+#endif
+/* Serial drivers */
+#define CONFIG_BAUDRATE 115200
/* The following table includes the supported baudrates */
#define CONFIG_SYS_BAUDRATE_TABLE \
{300, 600, 1200, 2400, 4800, 9600, 19200, 38400, 57600, 115200, 230400}
-#define CONFIG_BAUDRATE 115200
-
-/* XPSS Serial driver */
+/* Zynq Serial driver */
#define CONFIG_ZYNQ_SERIAL
#define CONFIG_ZYNQ_SERIAL_BASEADDR0 0xE0001000
#define CONFIG_ZYNQ_SERIAL_BAUDRATE0 CONFIG_BAUDRATE
#define CONFIG_ZYNQ_SERIAL_CLOCK0 50000000
+/* DCC driver */
+#if defined(CONFIG_ZYNQ_DCC)
+# define CONFIG_ARM_DCC
+# define CONFIG_CPU_V6 /* Required by CONFIG_ARM_DCC */
+#endif
+
/* Ethernet driver */
#define CONFIG_NET_MULTI
#define CONFIG_ZYNQ_GEM
#define CONFIG_ZYNQ_GEM0
#define CONFIG_ZYNQ_GEM_PHY_ADDR0 7
-#define CONFIG_ZYNQ_SDHCI
-#define CONFIG_ZYNQ_SDHCI0
+#define CONFIG_ZYNQ_SPI
+/* SPI */
+#ifdef CONFIG_ZYNQ_SPI
+# define CONFIG_SPI_FLASH
+# define CONFIG_SPI_FLASH_SST
+# define CONFIG_CMD_SF
+#endif
+
+/* NOR */
+#define CONFIG_SYS_NO_FLASH
+#define CONFIG_ZYNQ_SDHCI0
/* MMC */
#if defined(CONFIG_ZYNQ_SDHCI0) || defined(CONFIG_ZYNQ_SDHCI1)
# define CONFIG_MMC
@@ -48,7 +66,6 @@
#endif
#define CONFIG_ZYNQ_I2C0
-
/* I2C */
#if defined(CONFIG_ZYNQ_I2C0) || defined(CONFIG_ZYNQ_I2C1)
# define CONFIG_CMD_I2C
@@ -58,26 +75,6 @@
# define CONFIG_SYS_I2C_ZYNQ_SLAVE 1
#endif
-#if defined(CONFIG_ZYNQ_DCC)
-# define CONFIG_ARM_DCC
-# define CONFIG_CPU_V6 /* Required by CONFIG_ARM_DCC */
-#endif
-
-#define CONFIG_ZYNQ_SPI
-
-/* SPI */
-#ifdef CONFIG_ZYNQ_SPI
-# define CONFIG_SPI_FLASH
-# define CONFIG_SPI_FLASH_SST
-# define CONFIG_CMD_SF
-#endif
-
-/* Enable the PL to be downloaded */
-#define CONFIG_FPGA
-#define CONFIG_FPGA_XILINX
-#define CONFIG_FPGA_ZYNQPL
-#define CONFIG_CMD_FPGA
-
#define CONFIG_BOOTP_SERVERIP
#define CONFIG_BOOTP_BOOTPATH
#define CONFIG_BOOTP_GATEWAY
@@ -91,12 +88,9 @@
#define CONFIG_PHY_MARVELL
/* Environment */
+#define CONFIG_ENV_SIZE 0x10000 /* Env. sector size */
#define CONFIG_ENV_IS_NOWHERE
-#define CONFIG_ENV_SIZE 0x10000
-
-#define CONFIG_SYS_NO_FLASH
-
-#define CONFIG_SYS_MALLOC_LEN 0x400000
+#define CONFIG_SYS_LOAD_ADDR 0
/* Miscellaneous configurable options */
#define CONFIG_SYS_PROMPT "zynq-uboot> "
@@ -110,8 +104,6 @@
#define CONFIG_SYS_PBSIZE (CONFIG_SYS_CBSIZE + \
sizeof(CONFIG_SYS_PROMPT) + 16)
-#define CONFIG_SYS_LOAD_ADDR 0
-
/* Physical Memory map */
#define CONFIG_SYS_TEXT_BASE 0
@@ -122,15 +114,25 @@
#define CONFIG_SYS_MEMTEST_START CONFIG_SYS_SDRAM_BASE
#define CONFIG_SYS_MEMTEST_END (CONFIG_SYS_SDRAM_BASE + 0x1000)
+#define CONFIG_SYS_MALLOC_LEN 0x400000
#define CONFIG_SYS_INIT_RAM_ADDR CONFIG_SYS_SDRAM_BASE
#define CONFIG_SYS_INIT_RAM_SIZE CONFIG_SYS_MALLOC_LEN
#define CONFIG_SYS_INIT_SP_ADDR (CONFIG_SYS_INIT_RAM_ADDR + \
CONFIG_SYS_INIT_RAM_SIZE - \
GENERATED_GBL_DATA_SIZE)
-/* OF */
+
+/* Enable the PL to be downloaded */
+#define CONFIG_FPGA
+#define CONFIG_FPGA_XILINX
+#define CONFIG_FPGA_ZYNQPL
+#define CONFIG_CMD_FPGA
+
+/* Open Firmware flat tree */
+#define CONFIG_OF_LIBFDT
+
+/* FIT support */
#define CONFIG_FIT
#define CONFIG_FIT_VERBOSE 1 /* enable fit_format_{error,warning}() */
-#define CONFIG_OF_LIBFDT
/* Boot FreeBSD/vxWorks from an ELF image */
#if defined(CONFIG_ZYNQ_BOOT_FREEBSD)
--
1.8.3
^ permalink raw reply related
* [U-Boot] [PATCH v2 04/35] zynq: Cleanup on memory configs
From: Jagannadha Sutradharudu Teki @ 2013-12-18 15:29 UTC (permalink / raw)
To: u-boot
In-Reply-To: <1387380620-29228-1-git-send-email-jaganna@xilinx.com>
Cleanup on memory configuration options:
- Add comment
- Re-order configs
Signed-off-by: Jagannadha Sutradharudu Teki <jaganna@xilinx.com>
---
V2: none
include/configs/zynq.h | 27 ++++++++++++++-------------
1 file changed, 14 insertions(+), 13 deletions(-)
diff --git a/include/configs/zynq.h b/include/configs/zynq.h
index e34024d..8be52df 100644
--- a/include/configs/zynq.h
+++ b/include/configs/zynq.h
@@ -13,14 +13,6 @@
/* CPU clock */
#define CONFIG_CPU_FREQ_HZ 800000000
-/* Ram */
-#define CONFIG_NR_DRAM_BANKS 1
-#define CONFIG_SYS_TEXT_BASE 0
-#define CONFIG_SYS_SDRAM_BASE 0
-#define CONFIG_SYS_SDRAM_SIZE 0x40000000
-#define CONFIG_SYS_MEMTEST_START CONFIG_SYS_SDRAM_BASE
-#define CONFIG_SYS_MEMTEST_END (CONFIG_SYS_SDRAM_BASE + 0x1000)
-
/* The following table includes the supported baudrates */
#define CONFIG_SYS_BAUDRATE_TABLE \
{300, 600, 1200, 2400, 4800, 9600, 19200, 38400, 57600, 115200, 230400}
@@ -105,11 +97,6 @@
#define CONFIG_SYS_NO_FLASH
#define CONFIG_SYS_MALLOC_LEN 0x400000
-#define CONFIG_SYS_INIT_RAM_ADDR CONFIG_SYS_SDRAM_BASE
-#define CONFIG_SYS_INIT_RAM_SIZE CONFIG_SYS_MALLOC_LEN
-#define CONFIG_SYS_INIT_SP_ADDR (CONFIG_SYS_INIT_RAM_ADDR + \
- CONFIG_SYS_INIT_RAM_SIZE - \
- GENERATED_GBL_DATA_SIZE)
/* Miscellaneous configurable options */
#define CONFIG_SYS_PROMPT "zynq-uboot> "
@@ -125,7 +112,21 @@
#define CONFIG_SYS_LOAD_ADDR 0
+/* Physical Memory map */
+#define CONFIG_SYS_TEXT_BASE 0
+#define CONFIG_NR_DRAM_BANKS 1
+#define CONFIG_SYS_SDRAM_BASE 0
+#define CONFIG_SYS_SDRAM_SIZE 0x40000000
+
+#define CONFIG_SYS_MEMTEST_START CONFIG_SYS_SDRAM_BASE
+#define CONFIG_SYS_MEMTEST_END (CONFIG_SYS_SDRAM_BASE + 0x1000)
+
+#define CONFIG_SYS_INIT_RAM_ADDR CONFIG_SYS_SDRAM_BASE
+#define CONFIG_SYS_INIT_RAM_SIZE CONFIG_SYS_MALLOC_LEN
+#define CONFIG_SYS_INIT_SP_ADDR (CONFIG_SYS_INIT_RAM_ADDR + \
+ CONFIG_SYS_INIT_RAM_SIZE - \
+ GENERATED_GBL_DATA_SIZE)
/* OF */
#define CONFIG_FIT
#define CONFIG_FIT_VERBOSE 1 /* enable fit_format_{error,warning}() */
--
1.8.3
^ permalink raw reply related
* [U-Boot] [PATCH v2 03/35] zynq: Cleanup on miscellaneous configs
From: Jagannadha Sutradharudu Teki @ 2013-12-18 15:29 UTC (permalink / raw)
To: u-boot
In-Reply-To: <1387380620-29228-1-git-send-email-jaganna@xilinx.com>
Cleanup on miscellaneous configurable options:
- Rename SYS_PROMPT as "zynq-uboot"
- Add comment
- Re-order configs
Signed-off-by: Jagannadha Sutradharudu Teki <jaganna@xilinx.com>
---
V2: Removed CONFIG_SYS_PROMPT_HUSH_PS2
include/configs/zynq.h | 19 ++++++++++---------
1 file changed, 10 insertions(+), 9 deletions(-)
diff --git a/include/configs/zynq.h b/include/configs/zynq.h
index 0492818..e34024d 100644
--- a/include/configs/zynq.h
+++ b/include/configs/zynq.h
@@ -111,19 +111,20 @@
CONFIG_SYS_INIT_RAM_SIZE - \
GENERATED_GBL_DATA_SIZE)
-#define CONFIG_SYS_PROMPT "U-Boot> "
-#define CONFIG_SYS_CBSIZE 256 /* Console I/O Buffer Size */
-#define CONFIG_SYS_PBSIZE (CONFIG_SYS_CBSIZE + \
+/* Miscellaneous configurable options */
+#define CONFIG_SYS_PROMPT "zynq-uboot> "
+#define CONFIG_SYS_HUSH_PARSER
+
+#define CONFIG_CMDLINE_EDITING
+#define CONFIG_AUTO_COMPLETE
+#define CONFIG_SYS_LONGHELP
+#define CONFIG_SYS_MAXARGS 15 /* max number of command args */
+#define CONFIG_SYS_CBSIZE 256 /* Console I/O Buffer Size */
+#define CONFIG_SYS_PBSIZE (CONFIG_SYS_CBSIZE + \
sizeof(CONFIG_SYS_PROMPT) + 16)
#define CONFIG_SYS_LOAD_ADDR 0
-#define CONFIG_SYS_MAXARGS 15 /* max number of command args */
-#define CONFIG_SYS_LONGHELP
-#define CONFIG_AUTO_COMPLETE
-#define CONFIG_CMDLINE_EDITING
-#define CONFIG_SYS_HUSH_PARSER
-#define CONFIG_SYS_PROMPT_HUSH_PS2 "> "
/* OF */
#define CONFIG_FIT
--
1.8.3
^ permalink raw reply related
* [U-Boot] [PATCH v2 02/35] zynq: Enable Boot FreeBSD/vxWorks
From: Jagannadha Sutradharudu Teki @ 2013-12-18 15:29 UTC (permalink / raw)
To: u-boot
In-Reply-To: <1387380620-29228-1-git-send-email-jaganna@xilinx.com>
This enabled Boot FreeBSD/vxWorks from an ELF image support
Signed-off-by: Jagannadha Sutradharudu Teki <jaganna@xilinx.com>
---
V2: none
include/configs/zynq.h | 7 +++++++
1 file changed, 7 insertions(+)
diff --git a/include/configs/zynq.h b/include/configs/zynq.h
index 6019c4a..0492818 100644
--- a/include/configs/zynq.h
+++ b/include/configs/zynq.h
@@ -130,6 +130,13 @@
#define CONFIG_FIT_VERBOSE 1 /* enable fit_format_{error,warning}() */
#define CONFIG_OF_LIBFDT
+/* Boot FreeBSD/vxWorks from an ELF image */
+#if defined(CONFIG_ZYNQ_BOOT_FREEBSD)
+# define CONFIG_API
+# define CONFIG_CMD_ELF
+# define CONFIG_SYS_MMC_MAX_DEVICE 1
+#endif
+
/* Commands */
#include <config_cmd_default.h>
--
1.8.3
^ permalink raw reply related
* [U-Boot] [PATCH v2 01/35] zynq: Enable CONFIG_FIT_VERBOSE
From: Jagannadha Sutradharudu Teki @ 2013-12-18 15:29 UTC (permalink / raw)
To: u-boot
In-Reply-To: <1387380620-29228-1-git-send-email-jaganna@xilinx.com>
Enabled fit_format_{error,warning}()
Signed-off-by: Jagannadha Sutradharudu Teki <jaganna@xilinx.com>
---
V2: none
include/configs/zynq.h | 1 +
1 file changed, 1 insertion(+)
diff --git a/include/configs/zynq.h b/include/configs/zynq.h
index 82ec826..6019c4a 100644
--- a/include/configs/zynq.h
+++ b/include/configs/zynq.h
@@ -127,6 +127,7 @@
/* OF */
#define CONFIG_FIT
+#define CONFIG_FIT_VERBOSE 1 /* enable fit_format_{error,warning}() */
#define CONFIG_OF_LIBFDT
/* Commands */
--
1.8.3
^ permalink raw reply related
* [U-Boot] [PATCH v2 00/35] zynq: More boards support
From: Jagannadha Sutradharudu Teki @ 2013-12-18 15:29 UTC (permalink / raw)
To: u-boot
These changes are from u-boot-xlnx.git repo from git.xilinx.com
This repo is well tested on xilinx zynq platform, hence pushing
the same on upstream.
--
Thanks,
Jagan.
Jagannadha Sutradharudu Teki (35):
zynq: Enable CONFIG_FIT_VERBOSE
zynq: Enable Boot FreeBSD/vxWorks
zynq: Cleanup on miscellaneous configs
zynq: Cleanup on memory configs
zynq: Minor config cleanup
zynq: Enable cache options
zynq: Add UART0, UART1 configs support
zynq: Add GEM0, GEM1 configs support
zynq-common: Rename zynq with zynq-common
zynq: Add support to find bootmode
spi: Add zynq qspi controller driver
zynq-common: Enable CONFIG_ZYNQ_QSPI
zynq: Add zynq zc70x board support
zynq: Add zynq zed board support
zynq-common: Define CONFIG_SPI_FLASH_BAR
zynq: Move CONFIG_SYS_SDRAM_SIZE to pre-board configs
zynq-common: Define exact TEXT_BASE
zynq: zc70x: Add Catalyst 24WC08 EEPROM config support
zynq: Add zynq microzed board support
zynq: Add zynq_zc770 xm010 board support
zynq: Add zynq_zc770 xm013 board support
zynq: Add zynq_zc770 xm012 board support
nand: Add zynq nand controller driver support
zynq-common: Define CONFIG_NAND_ZYNQ
zynq: Add zynq_zc770 xm011 board support
zynq: Add support to find bootmode
zynq-common: Define default environment
zynq-common: Change Env. Sector size to 128Kb
zynq-common: Define flash env. partition
zynq-common: Define CONFIG_ENV_OVERWRITE
dts: zynq: Add basic fdt support
gpio: zynq: Add dummy gpio routines
zynq-common: Enable verified boot(RSA)
dts: zynq: Add more zynq dts files
doc: Update the zynq u-boot status
README | 4 +
arch/arm/cpu/armv7/zynq/slcr.c | 6 +
arch/arm/dts/zynq-7000.dtsi | 13 +
arch/arm/include/asm/arch-zynq/gpio.h | 25 +
arch/arm/include/asm/arch-zynq/hardware.h | 3 +
arch/arm/include/asm/arch-zynq/sys_proto.h | 1 +
board/xilinx/dts/zynq-microzed.dts | 14 +
board/xilinx/dts/zynq-zc702.dts | 14 +
board/xilinx/dts/zynq-zc706.dts | 14 +
board/xilinx/dts/zynq-zc770-xm010.dts | 14 +
board/xilinx/dts/zynq-zc770-xm011.dts | 14 +
board/xilinx/dts/zynq-zc770-xm012.dts | 14 +
board/xilinx/dts/zynq-zc770-xm013.dts | 14 +
board/xilinx/dts/zynq-zed.dts | 14 +
board/xilinx/zynq/board.c | 33 +
boards.cfg | 9 +-
doc/README.zynq | 92 +++
drivers/mtd/nand/Makefile | 1 +
drivers/mtd/nand/zynq_nand.c | 1198 ++++++++++++++++++++++++++++
drivers/spi/Makefile | 1 +
drivers/spi/zynq_qspi.c | 449 +++++++++++
include/configs/zynq-common.h | 270 +++++++
include/configs/zynq.h | 139 ----
include/configs/zynq_microzed.h | 26 +
include/configs/zynq_zc70x.h | 29 +
include/configs/zynq_zc770.h | 44 +
include/configs/zynq_zed.h | 27 +
27 files changed, 2341 insertions(+), 141 deletions(-)
create mode 100644 arch/arm/dts/zynq-7000.dtsi
create mode 100644 arch/arm/include/asm/arch-zynq/gpio.h
create mode 100644 board/xilinx/dts/zynq-microzed.dts
create mode 100644 board/xilinx/dts/zynq-zc702.dts
create mode 100644 board/xilinx/dts/zynq-zc706.dts
create mode 100644 board/xilinx/dts/zynq-zc770-xm010.dts
create mode 100644 board/xilinx/dts/zynq-zc770-xm011.dts
create mode 100644 board/xilinx/dts/zynq-zc770-xm012.dts
create mode 100644 board/xilinx/dts/zynq-zc770-xm013.dts
create mode 100644 board/xilinx/dts/zynq-zed.dts
create mode 100644 doc/README.zynq
create mode 100644 drivers/mtd/nand/zynq_nand.c
create mode 100644 drivers/spi/zynq_qspi.c
create mode 100644 include/configs/zynq-common.h
delete mode 100644 include/configs/zynq.h
create mode 100644 include/configs/zynq_microzed.h
create mode 100644 include/configs/zynq_zc70x.h
create mode 100644 include/configs/zynq_zc770.h
create mode 100644 include/configs/zynq_zed.h
--
1.8.3
^ permalink raw reply
* [U-Boot] [PATCH] mmc/dwmmc: Using calloc instead malloc
From: Alexey Brodkin @ 2013-12-18 15:22 UTC (permalink / raw)
To: u-boot
In-Reply-To: <1387379331-2909-1-git-send-email-clsee@altera.com>
On Wed, 2013-12-18 at 09:08 -0600, Chin Liang See wrote:
> To enhance the SDMMC DesignWare driver to use calloc instead of
> malloc. This will avoid the incident that uninitialized members
> of mmc structure are later used for NULL comparison.
>
IMHO pretty sane change.
Actually I had local memset right after this malloc to make sure all
members are zeroed.
But with this change we have a clean structure right away.
I'm wondering why "calloc" is not used in every driver for device
specific structure allocation.
-Alexey
^ permalink raw reply
* [U-Boot] [PATCH] mmc/dwmmc: Using calloc instead malloc
From: Chin Liang See @ 2013-12-18 15:08 UTC (permalink / raw)
To: u-boot
To enhance the SDMMC DesignWare driver to use calloc instead of
malloc. This will avoid the incident that uninitialized members
of mmc structure are later used for NULL comparison.
Signed-off-by: Chin Liang See <clsee@altera.com>
Cc: Rajeshwari Shinde <rajeshwari.s@samsung.com>
Cc: Jaehoon Chung <jh80.chung@samsung.com>
Cc: Mischa Jonker <mjonker@synopsys.com>
Cc: Alexey Brodkin <abrodkin@synopsys.com>
Cc: Andy Fleming <afleming@freescale.com>
---
drivers/mmc/dw_mmc.c | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
mode change 100644 => 100755 drivers/mmc/dw_mmc.c
diff --git a/drivers/mmc/dw_mmc.c b/drivers/mmc/dw_mmc.c
old mode 100644
new mode 100755
index 19d9b0b..82abe19
--- a/drivers/mmc/dw_mmc.c
+++ b/drivers/mmc/dw_mmc.c
@@ -336,9 +336,9 @@ int add_dwmci(struct dwmci_host *host, u32 max_clk, u32 min_clk)
struct mmc *mmc;
int err = 0;
- mmc = malloc(sizeof(struct mmc));
+ mmc = calloc(sizeof(struct mmc), 1);
if (!mmc) {
- printf("mmc malloc fail!\n");
+ printf("mmc calloc fail!\n");
return -1;
}
--
1.7.9.5
^ permalink raw reply related
* [U-Boot] [PATCH v2 0/5] fix and update LP-8x4x to boot DT kernel
From: Marek Vasut @ 2013-12-18 15:01 UTC (permalink / raw)
To: u-boot
In-Reply-To: <1387242224-22495-1-git-send-email-ynvich@gmail.com>
On Tuesday, December 17, 2013 at 02:03:39 AM, Sergei Ianovich wrote:
> Linux kernel maintainers require new machnines to support device
> tree boot. The config for LP-8x4x needs updating.
>
> In addition, there are a few fixes to board's configuration.
>
> v2 fixes review comments made by Marek Vasut.
>
> Sergei Ianovich (5):
> ARM: pxa: prevent PXA270 occasional reboot freezes
> arm: pxa: fix LP-8x4x USB support
> arm: pxa: fix 2nd flash chip address on LP-8x4x
> arm: pxa: update LP-8x4x to boot DT kernel
> arm: pxa: init ethaddr for LP-8x4x using DT
>
> arch/arm/cpu/pxa/pxa2xx.c | 1 +
> board/icpdas/lp8x4x/lp8x4x.c | 39 +++++++++++++--------------------------
> include/configs/lp8x4x.h | 15 +++++++--------
> 3 files changed, 21 insertions(+), 34 deletions(-)
Applied 1,3,4,5 , thanks!
2 doesn't apply so see my comment please.
Best regards,
Marek Vasut
^ permalink raw reply
* [U-Boot] [PATCH v2 2/5] arm: pxa: fix LP-8x4x USB support
From: Marek Vasut @ 2013-12-18 15:01 UTC (permalink / raw)
To: u-boot
In-Reply-To: <1387242224-22495-3-git-send-email-ynvich@gmail.com>
On Tuesday, December 17, 2013 at 02:03:41 AM, Sergei Ianovich wrote:
> USB was broken initially. Power polarity should be direct.
>
> Signed-off-by: Sergei Ianovich <ynvich@gmail.com>
> CC: Marek Vasut <marex@denx.de>
I pushed new u-boot-pxa/master, can you please rebase this one patch and repost?
Best regards,
Marek Vasut
^ permalink raw reply
* [U-Boot] Pull request: u-boot-sh/master
From: Tom Rini @ 2013-12-18 14:56 UTC (permalink / raw)
To: u-boot
In-Reply-To: <CABMQnVJ0MUOqvQvaih=UEJ-=X=x66EGPhgU1yycJUt-RgV57Yg@mail.gmail.com>
On Wed, Dec 18, 2013 at 04:56:42PM +0900, Nobuhiro Iwamatsu wrote:
> Dear Tom Rini.
>
> Please pull u-boot-sh master branch.
>
> Best regards,
> Nobuhiro
>
> The following changes since commit fd44194945714a478fab6407c04453caaef0bac9:
>
> Prepare v2014.01-rc2 (2013-12-16 13:07:05 -0500)
>
> are available in the git repository at:
>
> git://git.denx.de/u-boot-sh master
>
> for you to fetch changes up to f3bf212abc4139f12b472e97c1992ab32671b609:
>
> serial_sh: add support for SH7753 (2013-12-18 16:50:00 +0900)
>
> ----------------------------------------------------------------
> Yoshihiro Shimoda (3):
> sh: add support for sh7753evb board
> net: sh-eth: add support for SH7753
> serial_sh: add support for SH7753
>
> arch/sh/include/asm/cpu_sh4.h | 2 +
> arch/sh/include/asm/cpu_sh7753.h | 197
> +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
> board/renesas/sh7753evb/Makefile | 7 +++
> board/renesas/sh7753evb/lowlevel_init.S | 416
> ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
> board/renesas/sh7753evb/sh7753evb.c | 326
> +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
> board/renesas/sh7753evb/spi-boot.c | 134
> ++++++++++++++++++++++++++++++++++++++++++++++
> board/renesas/sh7753evb/u-boot.lds | 81 ++++++++++++++++++++++++++++
> boards.cfg | 1 +
> doc/README.sh7753evb | 67 +++++++++++++++++++++++
> drivers/net/sh_eth.h | 8 ++-
> drivers/serial/serial_sh.h | 4 +-
> include/configs/sh7753evb.h | 137
> +++++++++++++++++++++++++++++++++++++++++++++++
> 12 files changed, 1377 insertions(+), 3 deletions(-)
> create mode 100644 arch/sh/include/asm/cpu_sh7753.h
> create mode 100644 board/renesas/sh7753evb/Makefile
> create mode 100644 board/renesas/sh7753evb/lowlevel_init.S
> create mode 100644 board/renesas/sh7753evb/sh7753evb.c
> create mode 100644 board/renesas/sh7753evb/spi-boot.c
> create mode 100644 board/renesas/sh7753evb/u-boot.lds
> create mode 100644 doc/README.sh7753evb
> create mode 100644 include/configs/sh7753evb.h
Applied to u-boot/master, thanks!
--
Tom
-------------- next part --------------
A non-text attachment was scrubbed...
Name: not available
Type: application/pgp-signature
Size: 836 bytes
Desc: Digital signature
URL: <http://lists.denx.de/pipermail/u-boot/attachments/20131218/fe900922/attachment.pgp>
^ permalink raw reply
* [U-Boot] [PATCH 2/2] usb: gadget: fotg210: EP0 fifo empty indication is non-reliable
From: Marek Vasut @ 2013-12-18 14:55 UTC (permalink / raw)
To: u-boot
In-Reply-To: <1387351489-2008-3-git-send-email-dantesu@gmail.com>
On Wednesday, December 18, 2013 at 08:24:49 AM, Kuo-Jung Su wrote:
> From: Kuo-Jung Su <dantesu@faraday-tech.com>
>
> Because the EP0 fifo empty indication is non-reliable,
> an extra delay is necessary to avoid data corruption while
> handling packets with size greater than 64 bytes.
>
> This workaround should be applied to all hardware revisions.
>
> Signed-off-by: Kuo-Jung Su <dantesu@faraday-tech.com>
> CC: Marek Vasut <marex@denx.de>
> ---
> drivers/usb/gadget/fotg210.c | 1 +
> 1 file changed, 1 insertion(+)
>
> diff --git a/drivers/usb/gadget/fotg210.c b/drivers/usb/gadget/fotg210.c
> index e3a61cc..14bfec6 100644
> --- a/drivers/usb/gadget/fotg210.c
> +++ b/drivers/usb/gadget/fotg210.c
> @@ -245,6 +245,7 @@ static int fotg210_dma(struct fotg210_ep *ep, struct
> fotg210_request *req) if (ep->id == 0) {
> /* Wait until cx/ep0 fifo empty */
> fotg210_cxwait(chip, CXFIFO_CXFIFOE);
> + udelay_masked(1);
Why don't you use regular udelay() here please ? Also, how exactly does the
delay help solving the unreliability problem please?
> writel(DMAFIFO_CX, ®s->dma_fifo);
> } else {
> /* Wait until epx fifo empty */
Best regards,
Marek Vasut
^ permalink raw reply
* [U-Boot] [PATCH 1/2] usb: gadget: fotg210: add w1c interrupt status support
From: Marek Vasut @ 2013-12-18 14:54 UTC (permalink / raw)
To: u-boot
In-Reply-To: <1387351489-2008-2-git-send-email-dantesu@gmail.com>
On Wednesday, December 18, 2013 at 08:24:48 AM, Kuo-Jung Su wrote:
> From: Kuo-Jung Su <dantesu@faraday-tech.com>
>
> Since hardware revision 1.11.0, the following interrupt status registers
> are now write-1-clear (w1c):
What did they look like before ?
> 1. Interrupt Source Group 0 Register (0x144) (EP0 Abort: BIT5)
> 2. Interrupt Source Group 2 Register (0x14C) (All bits)
>
> Signed-off-by: Kuo-Jung Su <dantesu@faraday-tech.com>
> CC: Marek Vasut <marex@denx.de>
> ---
> drivers/usb/gadget/fotg210.c | 10 ++++++++--
> 1 file changed, 8 insertions(+), 2 deletions(-)
>
> diff --git a/drivers/usb/gadget/fotg210.c b/drivers/usb/gadget/fotg210.c
> index 6e19db1..e3a61cc 100644
> --- a/drivers/usb/gadget/fotg210.c
> +++ b/drivers/usb/gadget/fotg210.c
> @@ -847,8 +847,11 @@ int usb_gadget_handle_interrupts(void)
> /* CX interrupts */
> if (gisr & GISR_GRP0) {
> st = readl(®s->gisr0);
> +#ifdef CONFIG_USB_GADGET_FOTG210_ISRW1C
Can we not get rid of this ifdef somehow please ? Like detect the revision on-
the-fly and handle the bit accordingly or such ?
Best regards,
Marek Vasut
^ permalink raw reply
* [U-Boot] [PATCH] board:trats1:trats2: fix adapter number
From: Piotr Wilczek @ 2013-12-18 14:43 UTC (permalink / raw)
To: u-boot
This fix is necessary after increased by one the number
of adapters in s3c24x0 driver.
Tested on Trats and Trats2.
Signed-off-by: Piotr Wilczek <p.wilczek@samsung.com>
Signed-off-by: Kyungmin Park <kyungmin.park@samsung.com>
Cc: Minkyu Kang <mk7.kang@samsung.com>
Cc: Lukasz Majewski <l.majewski@samsung.com>
---
board/samsung/trats/trats.c | 2 +-
board/samsung/trats2/trats2.c | 6 +++---
2 files changed, 4 insertions(+), 4 deletions(-)
diff --git a/board/samsung/trats/trats.c b/board/samsung/trats/trats.c
index 8aba51c..640a193 100644
--- a/board/samsung/trats/trats.c
+++ b/board/samsung/trats/trats.c
@@ -295,7 +295,7 @@ int power_init_board(void)
*/
ret = pmic_init(I2C_5);
ret |= pmic_init_max8997();
- ret |= power_fg_init(I2C_8);
+ ret |= power_fg_init(I2C_9);
ret |= power_muic_init(I2C_5);
ret |= power_bat_init(0);
if (ret)
--
1.7.9.5
^ permalink raw reply related
* [U-Boot] "arm: keep all sections in ELF file" breaks Arndale
From: Andre Przywara @ 2013-12-18 14:06 UTC (permalink / raw)
To: u-boot
In-Reply-To: <52B0747C.9070503@ti.com>
On 12/17/2013 04:57 PM, Tom Rini wrote:
> -----BEGIN PGP SIGNED MESSAGE-----
> Hash: SHA1
>
> On 12/17/2013 10:47 AM, Andre Przywara wrote:
>> (CCing Inderpal, Chander and Minkyu)
>>
>> On 12/17/2013 04:30 PM, Tom Rini wrote:
>> On 12/17/2013 10:24 AM, Andre Przywara wrote:
>>>>> Hi,
>>>>>
>>>>> the Arndale board does not work anymore with current master HEAD.
>>>>> If I turn on the board, I see exactly nothing.
>>>>>
>>>>> I bisected it down to:
>>>>> 47ed5dd031d7d2c587e6afd386e79ccec1a1b7f7 is the first bad commit
>>>>> commit 47ed5dd031d7d2c587e6afd386e79ccec1a1b7f7
>>>>> Author: Albert ARIBAUD <albert.u.boot@aribaud.net>
>>>>> Date: Thu Nov 7 14:21:46 2013 +0100
>>>>>
>>>>> arm: keep all sections in ELF file
>>>>>
>>>>> That patch looks like Chinese to me, does one of you have an idea what's
>>>>> wrong here?
>>>>> Are we missing a section, maybe for the SPL build?
>>
>> So on Arndale, what file do you boot exactly? It sounds like not
>> u-boot.img but some tool stripping / modifying u-boot (or
>> spl/u-boot-spl) and having relied on certain sections being stripped out
>> before being run.
>>
>>> Good point. Indeed I boot u-boot-dtb.bin (the SPL is
>>> spl/arndale-spl.bin). So the Makefile does:
>>> cat u-boot.bin u-boot.dtb >u-boot-dtb.bin
>>
>>> I guess the address under which U-boot expects to find the attached dtb
>>> changes due to the non-discarding.
>>
>>> Does any of the Arndale people have an idea how to fix this?
>
> That's a little confusing as we use objcopy -O binary to make
> u-boot.bin/u-boot-spl.bin and that would, I would think, drop these
> sections anyhow. But some checking of binary size with the patch in
> question locally reverted would help shed some light here.
So I did objdump -h on ./u-boot, the diff (sorted by the section name,
as the order of the section differed, and the size) is:
.ARM.attributes 0000002d
-.bss 00048b10
+.bss 00048b08
.bss_end 00000000
.bss_start 00000000
.comment 0000001c
@@ -14,8 +14,12 @@
.debug_loc 00045a4e
.debug_ranges 00006f70
.debug_str 000123b4
+.dynamic 00000080
+.dynstr 0000001d
+.dynsym 00000060
.got.plt 0000000c
.hash 0000002c
+.interp 00000011
.rel.dyn 00006fd8
.rodata 0000ae47
.text 0002cdf0
- works, + is broken.
+ is HEAD as of yesterday, - is the same with the patch in question
reverted. So the patch _adds_ some sections to the file.
u-boot-spl is exactly the same, for u-boot-spl.bin the broken version
ends earlier (but until then is identical). arndale-spl.bin (which I
flash) is different, though.
Arndale uses CONFIG_OF_SEPARATE, and .text stays the same AFAICS.
I can do some more debugging tomorrow, am grateful for any hints.
Regards,
Andre.
^ permalink raw reply
* [U-Boot] [PATCH v3 0/8] SATA support for omap5_uevm and dra7_evm
From: Tom Rini @ 2013-12-18 12:20 UTC (permalink / raw)
To: u-boot
In-Reply-To: <CAFqH_52xt7i-EgC2vpDXBEBoyWasYniXBpwYTySMHm=QmJ-JBA@mail.gmail.com>
-----BEGIN PGP SIGNED MESSAGE-----
Hash: SHA1
On 12/18/2013 06:31 AM, Enric Balletbo Serra wrote:
> Hi Roger,
>
> 2013/12/4 Tom Rini <trini@ti.com>:
>> On Mon, Nov 11, 2013 at 04:56:36PM +0200, Roger Quadros wrote:
>>
>>> Hi,
>>>
>>> This series adds SATA support for OMAP5 uevm and DRA7 evm.
>>>
>>> Patches are also availabe at
>>> git at github.com:rogerq/u-boot.git sata
>>>
>>> v3:
>>> - get rid of custom perror() macro, use printf
>>> - Fixed coding sytle issues
>>>
>>> v2:
>>> - Address review comments in the RFC series
>>> - Fix cache align error in the ahci driver
>>> - Added dra7 support
>>>
>>> cheers,
>>> -roger
>>>
>>> Roger Quadros (8):
>>> ahci: Error out with message on malloc() failure
>>> ahci: Fix cache align error messages
>>> ARM: OMAP5: Add Pipe3 PHY driver
>>> ARM: OMAP5: Add PRCM and Control information for SATA
>>> ARM: OMAP5: Add SATA platform glue
>>> ARM: omap5_uevm: Add SATA support
>>> ARM: DRA7xx: Add PRCM and Control information for SATA
>>> ARM: dra7_evm: Add SATA support
>>
>> Applied to u-boot-ti/master, thanks!
>>
>
> Now that this will go to mainline, I wonder to know if there is any
> plan to add SPL support to boot from SATA ?
I've talked ever so briefly with Dan Murphy about this because his
series that adds USB host support gets us ever further towards SATA SPL
support as both talk in block_dev_desc_t. I don't think anyone is
working on this today, but my gut says it shouldn't be too hard to add
on top.
- --
Tom
-----BEGIN PGP SIGNATURE-----
Version: GnuPG v1.4.11 (GNU/Linux)
Comment: Using GnuPG with Thunderbird - http://www.enigmail.net/
iQIcBAEBAgAGBQJSsZMBAAoJENk4IS6UOR1W1eMQAJ0L1I+QgHGGxbb5wXWZHxL8
4xm2do/WTar5IV1he5bzegVXu0viowd/+p4BAyw5JzijnJqw7g0A+71TsY9Z55u0
SCmTJ0TynUzJNL1PL/MUk25Q2THgJKDziG0WAj2Nv37deAOHuO+AnT3nLqlOESug
CBKJU9IpAtLvQQ3rNejffLqM7mYzLjNrLtqC1UoWYgU2IMHIWuLPSfgTnaJnXS70
QOHgm427fo4LnXfjJ6SobDTBqOs55Nw3Gl/S/v/c8/n9rGEF0S3q1G2dfEfnKj1S
bPzuWJagyj7zNblApyuoL0ZsE2D5aKfysBpR4YULpgOg1xYL/TPwjWtdoe3Cv9Y8
8vx8XJlSm+7FMp4VcrfiIpwSNFiioNlMpyB9vonwe8bz4d8P+l34Ln16aHYROFP0
utQMEhgmsZ+Xw8Pch5dnazpWs1jKMADVR+vJFBf+Svr3ZaUFujns5Lk//bZGwcyR
Ilhk6bis/ylCbFN6OI7Xg7LkQTUnvyO4/5Bhv30XklSAE9iclo1EG1wB3LE0qtL1
duCFg9hTF9mHIARHn96oCgpFkSilIWLTLsGSoai3W4WxNkTPeqBZsNNBQNo1acXg
trvESrQNLMHPGaq+gKV5SDzsJ1Nhe3Ib6TPHXO+6PyyA03Sqxl0bkQHwdOgR3343
rqZjCaPIHOWHZk4F40Tm
=K9+D
-----END PGP SIGNATURE-----
^ permalink raw reply
* [U-Boot] [PATCH v7] spi: Add support SH Quad SPI driver
From: Jagan Teki @ 2013-12-18 12:07 UTC (permalink / raw)
To: u-boot
In-Reply-To: <1387348315-25767-1-git-send-email-nobuhiro.iwamatsu.yj@renesas.com>
On Wednesday 18 December 2013 12:01 PM, Nobuhiro Iwamatsu wrote:
> This patch adds a driver for Renesas SoC's Quad SPI bus.
> This supports with 8 bits per transfer to use with SPI flash.
>
> Signed-off-by: Kouei Abe <kouei.abe.cp@renesas.com>
> Signed-off-by: Nobuhiro Iwamatsu <nobuhiro.iwamatsu.yj@renesas.com>
> Signed-off-by: Jagannadha Sutradharudu Teki <jaganna@xilinx.com>
> ---
>
> Changes for v7:
> - Add comments on each initialization steps and others.
> - Change to using clrbits_* and setbits_*.
> - Add documet file for test.
> Changes for v6:
> - Update Makefile to new style.
> Changes for v5:
> - Add print abort when call ctrlc().
> - Move source code in spi_xfer() which should be processed by
> spi_cs_activate().
> - Move source code in spi_xfer() which should be processed by
> spi_cs_deactivate().
> - Remove sh_qspi_xfer, move to spi_xfer().
> Changes for v4:
> - Added tabs
> - Added comments
> - Added sh_qspi_init()
> Changes for v3:
> - Change Queued to Quad.
> - Remove path of file from file header.
> - Use read* and write* directly instead of sh_qspi_write* sh_qspi_read*.
> - Change driver format.
> Changes for v2:
> - "SH QSPI" to "SH QSPI (Queued SPI)".
> - Remove magic number.
>
>
> doc/SPI/README.sh_qspi_test | 38 ++++++
> drivers/spi/Makefile | 1 +
> drivers/spi/sh_qspi.c | 277 ++++++++++++++++++++++++++++++++++++++++++++
> 3 files changed, 316 insertions(+)
> create mode 100644 doc/SPI/README.sh_qspi_test
> create mode 100644 drivers/spi/sh_qspi.c
>
> diff --git a/doc/SPI/README.sh_qspi_test b/doc/SPI/README.sh_qspi_test
> new file mode 100644
> index 0000000..8a33fec
> --- /dev/null
> +++ b/doc/SPI/README.sh_qspi_test
> @@ -0,0 +1,38 @@
> +-------------------------------------------------
> + Simple steps used to test the SH-QSPI at U-Boot
> +-------------------------------------------------
> +
> +#0, Currently, SH-QSPI is used by lager board (Renesas ARM SoC R8A7790)
> + and koelsch board (Renesas ARM SoC R8A7791). These boot from SPI ROM
> + basically. Thus, U-Boot start, SH-QSPI will is operating normally.
> +
> +#1, build U-Boot and load u-boot.bin
> +
> + => tftpboot 40000000 u-boot.bin
> + sh_eth Waiting for PHY auto negotiation to complete.. done
> + sh_eth: 100Base/Half
> + Using sh_eth device
> + TFTP from server 192.168.169.1; our IP address is 192.168.169.79
> + Filename 'u-boot.bin'.
> + Load address: 0x40000000
> + Loading: ############
> + 2.5 MiB/s
> + done
> + Bytes transferred = 175364 (2ad04 hex)
> +
> +#2, Commands to erase/write u-boot to flash device
> +
> + Note: This method is description of the lager board. If you want to use the
> + other boards, please change the value according to each environment.
> +
> + => sf probe 0
> + SF: Detected S25FL512S_256K with page size 512 Bytes, erase size 64 KiB, total 64 MiB
> + => sf erase 80000 40000
> + SF: 262144 bytes @ 0x80000 Erased: OK
> + => sf write 40000000 80000 175364
> + SF: 1528676 bytes @ 0x80000 Written: OK
> + =>
> +
> +#3, Push reset button.
> +
> + If you're written correctly and driver works properly, U-Boot starts.
> diff --git a/drivers/spi/Makefile b/drivers/spi/Makefile
> index 27902fe..914e71f 100644
> --- a/drivers/spi/Makefile
> +++ b/drivers/spi/Makefile
> @@ -29,6 +29,7 @@ obj-$(CONFIG_OC_TINY_SPI) += oc_tiny_spi.o
> obj-$(CONFIG_OMAP3_SPI) += omap3_spi.o
> obj-$(CONFIG_SOFT_SPI) += soft_spi.o
> obj-$(CONFIG_SH_SPI) += sh_spi.o
> +obj-$(CONFIG_SH_QSPI) += sh_qspi.o
> obj-$(CONFIG_FSL_ESPI) += fsl_espi.o
> obj-$(CONFIG_FDT_SPI) += fdt_spi.o
> obj-$(CONFIG_TEGRA20_SFLASH) += tegra20_sflash.o
> diff --git a/drivers/spi/sh_qspi.c b/drivers/spi/sh_qspi.c
> new file mode 100644
> index 0000000..edeb42d
> --- /dev/null
> +++ b/drivers/spi/sh_qspi.c
> @@ -0,0 +1,277 @@
> +/*
> + * SH QSPI (Quad SPI) driver
> + *
> + * Copyright (C) 2013 Renesas Electronics Corporation
> + * Copyright (C) 2013 Nobuhiro Iwamatsu <nobuhiro.iwamatsu.yj@renesas.com>
> + *
> + * SPDX-License-Identifier: GPL-2.0
> + */
> +
> +#include <common.h>
> +#include <malloc.h>
> +#include <spi.h>
> +#include <asm/io.h>
> +
> +/* SH QSPI register bit masks <REG>_<BIT> */
> +#define SPCR_MSTR 0x08
> +#define SPCR_SPE 0x40
> +#define SPSR_SPRFF 0x80
> +#define SPSR_SPTEF 0x20
> +#define SPPCR_IO3FV 0x04
> +#define SPPCR_IO2FV 0x02
> +#define SPPCR_IO1FV 0x01
> +#define SPBDCR_RXBC0 (1 << 0)
> +#define SPCMD_SCKDEN (1 << 15)
> +#define SPCMD_SLNDEN (1 << 14)
> +#define SPCMD_SPNDEN (1 << 13)
> +#define SPCMD_SSLKP (1 << 7)
> +#define SPCMD_BRDV0 (1 << 2)
> +#define SPCMD_INIT1 SPCMD_SCKDEN | SPCMD_SLNDEN | \
> + SPCMD_SPNDEN | SPCMD_SSLKP | \
> + SPCMD_BRDV0
> +#define SPCMD_INIT2 SPCMD_SPNDEN | SPCMD_SSLKP | \
> + SPCMD_BRDV0
> +#define SPBFCR_TXRST (1 << 7)
> +#define SPBFCR_RXRST (1 << 6)
> +
> +/* SH QSPI register set */
> +struct sh_qspi_regs {
> + unsigned char spcr;
> + unsigned char sslp;
> + unsigned char sppcr;
> + unsigned char spsr;
> + unsigned long spdr;
> + unsigned char spscr;
> + unsigned char spssr;
> + unsigned char spbr;
> + unsigned char spdcr;
> + unsigned char spckd;
> + unsigned char sslnd;
> + unsigned char spnd;
> + unsigned char dummy0;
> + unsigned short spcmd0;
> + unsigned short spcmd1;
> + unsigned short spcmd2;
> + unsigned short spcmd3;
> + unsigned char spbfcr;
> + unsigned char dummy1;
> + unsigned short spbdcr;
> + unsigned long spbmul0;
> + unsigned long spbmul1;
> + unsigned long spbmul2;
> + unsigned long spbmul3;
> +};
> +
> +struct sh_qspi_slave {
> + struct spi_slave slave;
> + struct sh_qspi_regs *regs;
> +};
> +
> +static inline struct sh_qspi_slave *to_sh_qspi(struct spi_slave *slave)
> +{
> + return container_of(slave, struct sh_qspi_slave, slave);
> +}
> +
> +static void sh_qspi_init(struct sh_qspi_slave *ss)
> +{
> + /* QSPI initialize */
> + /* Set master mode only */
> + writeb(SPCR_MSTR, &ss->regs->spcr);
> +
> + /* Set SSL signal level */
> + writeb(0x00, &ss->regs->sslp);
> +
> + /* Set MOSI signal value when transfer is in idle state */
> + writeb(SPPCR_IO3FV|SPPCR_IO2FV, &ss->regs->sppcr);
> +
> + /* Set bit rate. See 58.3.8 Quad Serial Peripheral Interface */
> + writeb(0x01, &ss->regs->spbr);
> +
> + /* Disable Dummy Data Transmission */
> + writeb(0x00, &ss->regs->spdcr);
> +
> + /* Set clock delay value */
> + writeb(0x00, &ss->regs->spckd);
> +
> + /* Set SSL negation delay value */
> + writeb(0x00, &ss->regs->sslnd);
> +
> + /* Set next-access delay value */
> + writeb(0x00, &ss->regs->spnd);
> +
> + /* Set equence command */
> + writew(SPCMD_INIT2, &ss->regs->spcmd0);
> +
> + /* Reset transfer and receive Buffer */
> + setbits_8(&ss->regs->spbfcr, SPBFCR_TXRST|SPBFCR_RXRST);
> +
> + /* Clear transfer and receive Buffer control bit */
> + clrbits_8(&ss->regs->spbfcr, SPBFCR_TXRST|SPBFCR_RXRST);
> +
> + /* Set equence control method. Use equence0 only */
> + writeb(0x00, &ss->regs->spscr);
> +
> + /* Enable SPI function */
> + setbits_8(&ss->regs->spcr, SPCR_SPE);
> +}
> +
> +int spi_cs_is_valid(unsigned int bus, unsigned int cs)
> +{
> + return 1;
> +}
> +
> +void spi_cs_activate(struct spi_slave *slave)
> +{
> + struct sh_qspi_slave *ss = to_sh_qspi(slave);
> +
> + /* Set master mode only */
> + writeb(SPCR_MSTR, &ss->regs->spcr);
> +
> + /* Set command */
> + writew(SPCMD_INIT1, &ss->regs->spcmd0);
> +
> + /* Reset transfer and receive Buffer */
> + setbits_8(&ss->regs->spbfcr, SPBFCR_TXRST|SPBFCR_RXRST);
> +
> + /* Clear transfer and receive Buffer control bit */
> + clrbits_8(&ss->regs->spbfcr, SPBFCR_TXRST|SPBFCR_RXRST);
> +
> + /* Set equence control method. Use equence0 only */
> + writeb(0x00, &ss->regs->spscr);
> +
> + /* Enable SPI function */
> + setbits_8(&ss->regs->spcr, SPCR_SPE);
> +}
> +
> +void spi_cs_deactivate(struct spi_slave *slave)
> +{
> + struct sh_qspi_slave *ss = to_sh_qspi(slave);
> +
> + /* Disable SPI Function */
> + clrbits_8(&ss->regs->spcr, SPCR_SPE);
> +}
> +
> +void spi_init(void)
> +{
> + /* nothing to do */
> +}
> +
> +struct spi_slave *spi_setup_slave(unsigned int bus, unsigned int cs,
> + unsigned int max_hz, unsigned int mode)
> +{
> + struct sh_qspi_slave *ss;
> +
> + if (!spi_cs_is_valid(bus, cs))
> + return NULL;
> +
> + ss = spi_alloc_slave(struct sh_qspi_slave, bus, cs);
> + if (!ss) {
> + printf("SPI_error: Fail to allocate sh_qspi_slave\n");
> + return NULL;
> + }
> +
> + ss->regs = (struct sh_qspi_regs *)CONFIG_SH_QSPI_BASE;
> +
> + /* Init SH QSPI */
> + sh_qspi_init(ss);
> +
> + return &ss->slave;
> +}
> +
> +void spi_free_slave(struct spi_slave *slave)
> +{
> + struct sh_qspi_slave *spi = to_sh_qspi(slave);
> +
> + free(spi);
> +}
> +
> +int spi_claim_bus(struct spi_slave *slave)
> +{
> + return 0;
> +}
> +
> +void spi_release_bus(struct spi_slave *slave)
> +{
> +}
> +
> +int spi_xfer(struct spi_slave *slave, unsigned int bitlen, const void *dout,
> + void *din, unsigned long flags)
> +{
> + struct sh_qspi_slave *ss = to_sh_qspi(slave);
> + unsigned long nbyte;
> + int ret = 0;
> + unsigned char dtdata = 0, drdata;
> + unsigned char *tdata = &dtdata, *rdata = &drdata;
> + unsigned long *spbmul0 = &ss->regs->spbmul0;
> +
> + if (dout == NULL && din == NULL) {
> + if (flags & SPI_XFER_END)
> + spi_cs_deactivate(slave);
> + return 0;
> + }
> +
> + if (bitlen % 8) {
> + printf("%s: bitlen is not 8bit alined %d", __func__, bitlen);
> + return 1;
> + }
> +
> + nbyte = bitlen / 8;
> +
> + if (flags & SPI_XFER_BEGIN) {
> + spi_cs_activate(slave);
> +
> + /* Set 1048576 byte */
> + writel(0x100000, spbmul0);
> + }
> +
> + if (flags & SPI_XFER_END)
> + writel(nbyte, spbmul0);
> +
> + if (dout != NULL)
> + tdata = (unsigned char *)dout;
> +
> + if (din != NULL)
> + rdata = din;
> +
> + while (nbyte > 0) {
> + while (!(readb(&ss->regs->spsr) & SPSR_SPTEF)) {
> + if (ctrlc()) {
> + puts("abort\n");
> + return 1;
> + }
> + udelay(10);
> + }
> +
> + writeb(*tdata, (unsigned char *)(&ss->regs->spdr));
> +
> + while ((readw(&ss->regs->spbdcr) != SPBDCR_RXBC0)) {
> + if (ctrlc()) {
> + puts("abort\n");
> + return 1;
> + }
> + udelay(1);
> + }
> +
> + while (!(readb(&ss->regs->spsr) & SPSR_SPRFF)) {
> + if (ctrlc()) {
> + puts("abort\n");
> + return 1;
> + }
> + udelay(10);
> + }
> +
> + *rdata = readb((unsigned char *)(&ss->regs->spdr));
> +
> + if (dout != NULL)
> + tdata++;
> + if (din != NULL)
> + rdata++;
> +
> + nbyte--;
> + }
> +
> + if (flags & SPI_XFER_END)
> + spi_cs_deactivate(slave);
> +
> + return ret;
> +}
>
Fixed in driver/spi/Makefile changes.
Applied to u-boot-spi/master
--
Thanks,
Jagan.
This email and any attachments are intended for the sole use of the named recipient(s) and contain(s) confidential information that may be proprietary, privileged or copyrighted under applicable law. If you are not the intended recipient, do not read, copy, or forward this email message or any attachments. Delete this email message and any attachments immediately.
^ permalink raw reply
* [U-Boot] [PATCH v3 0/8] SATA support for omap5_uevm and dra7_evm
From: Enric Balletbo Serra @ 2013-12-18 11:31 UTC (permalink / raw)
To: u-boot
In-Reply-To: <20131204220549.GN420@bill-the-cat>
Hi Roger,
2013/12/4 Tom Rini <trini@ti.com>:
> On Mon, Nov 11, 2013 at 04:56:36PM +0200, Roger Quadros wrote:
>
>> Hi,
>>
>> This series adds SATA support for OMAP5 uevm and DRA7 evm.
>>
>> Patches are also availabe at
>> git at github.com:rogerq/u-boot.git sata
>>
>> v3:
>> - get rid of custom perror() macro, use printf
>> - Fixed coding sytle issues
>>
>> v2:
>> - Address review comments in the RFC series
>> - Fix cache align error in the ahci driver
>> - Added dra7 support
>>
>> cheers,
>> -roger
>>
>> Roger Quadros (8):
>> ahci: Error out with message on malloc() failure
>> ahci: Fix cache align error messages
>> ARM: OMAP5: Add Pipe3 PHY driver
>> ARM: OMAP5: Add PRCM and Control information for SATA
>> ARM: OMAP5: Add SATA platform glue
>> ARM: omap5_uevm: Add SATA support
>> ARM: DRA7xx: Add PRCM and Control information for SATA
>> ARM: dra7_evm: Add SATA support
>
> Applied to u-boot-ti/master, thanks!
>
Now that this will go to mainline, I wonder to know if there is any
plan to add SPL support to boot from SATA ?
Thanks,
Enric
> --
> Tom
>
> _______________________________________________
> U-Boot mailing list
> U-Boot at lists.denx.de
> http://lists.denx.de/mailman/listinfo/u-boot
>
^ permalink raw reply
* [U-Boot] [PATCH] Makefile: fix broken pipe error for lcd4_lwmon5 board
From: Masahiro Yamada @ 2013-12-18 10:03 UTC (permalink / raw)
To: u-boot
In-Reply-To: <52B16B8C.60808@denx.de>
Hello Stefan
> > Besides fixing a broken pipe error,
> > this commit gives us other advantages:
> >
> > - Do not generate intermidiate files, spl/u-boot-spl.img
> > and spl/u-boot-spl-pad.img for creating u-boot.spr
> >
> > - Do not generate an intermidiate file, u-boot-pad.img
> > for creating u-boot-img-spl-at-end.bin
> >
> > Such intermidiate files were not deleted by "make clean" or "make mrpropr".
> > Nor u-boot-pad.img was ignored by git.
> >
> > Signed-off-by: Masahiro Yamada <yamada.m@jp.panasonic.com>
>
> This looks like a nice improvement. Thanks!
>
> Acked-by: Stefan Roese <sr@denx.de>
Thanks for you review.
But I found a mistake.
I posted v2.
Best Regards
Masahiro Yamada
^ permalink raw reply
* [U-Boot] [PATCH v2] Makefile: fix broken pipe error for lcd4_lwmon5 board
From: Masahiro Yamada @ 2013-12-18 10:00 UTC (permalink / raw)
To: u-boot
Before this commit, a broken pipe error sometimes happened
when building lcd4_lwmon5 board with Buildman.
This commit re-writes build rules of
u-boot.spr and u-boot-img-spl-at-end.bin
more simply without using a pipe.
Besides fixing a broken pipe error,
this commit gives us other advantages:
- Do not generate intermidiate files, spl/u-boot-spl.img
and spl/u-boot-spl-pad.img for creating u-boot.spr
- Do not generate an intermidiate file, u-boot-pad.img
for creating u-boot-img-spl-at-end.bin
Such intermidiate files were not deleted by "make clean" or "make mrpropr".
Nor u-boot-pad.img was ignored by git.
Signed-off-by: Masahiro Yamada <yamada.m@jp.panasonic.com>
Acked-by: Stefan Roese <sr@denx.de>
---
Hello Simon.
I noticed a broken pipe error when I was using Buildman.
The error happens here:
$(obj)u-boot-img-spl-at-end.bin: $(obj)spl/u-boot-spl.bin $(obj)u-boot.img
tr "\000" "\377" < /dev/zero | dd ibs=1 count=$(CONFIG_UBOOT_PAD_TO) \
of=$(obj)u-boot-pad.img 2>/dev/null
I cannot understand why this error happens on Buildman.
(I have never seen it on MAKEALL script.)
Does the same error happen on your machine too?
Do you have any idea why this error happen?
What I did is as follows:
$ git checkout master
$ git describe
v2014.01-rc2
$ git checkout -b cosmetic
Add many cosmetic commits. Do not change any source files.
(For example, changing README files)
I think about 20 commits are enough.
$ git branch --set-upstream-to=master
$ tool/buildman/buildman -b cosmetic lcd4_lwmon5
No section: 'make-flags'
Building 21 commits for 1 boards (1 thread, 8 jobs per thread)
Cloning repo for thread 0
14 7 0 /21 lcd4_lwmon5
$ tools/buildman/buildman -se -b cosmetic
No section: 'make-flags'
Summary of 21 commits for 1194 boards (8 threads, 1 job per thread)
01: Prepare v2014.01-rc2
powerpc: + lcd4_lwmon5
+tr: write error: Broken pipe
+tr: write error
02: cosmetic1
powerpc: lcd4_lwmon5
-tr: write error: Broken pipe
-tr: write error
03: cosmetic2
04: cosmetic3
05: cosmetic4
06: cosmetic5
07: cosmetic6
08: cosmetic7
09: cosmetic8
10: cosmetic9
11: cosmetic10
12: cosmetic11
13: cosmetic12
14: cosmetic13
15: cosmetic14
16: cosmetic15
powerpc: + lcd4_lwmon5
+tr: write error: Broken pipe
+tr: write error
17: cosmetic16
18: cosmetic17
19: cosmetic18
20: cosmetic19
21: cosmetic20
Here, a broken pipe error occurred at 01 and fixed at 02.
It happend again at 16.
But the result changes every time.
The error happens randomly.
Changes in v2:
- Delete an unnecessary line
cp $(obj)u-boot.img $@
Makefile | 18 +++++++-----------
1 file changed, 7 insertions(+), 11 deletions(-)
diff --git a/Makefile b/Makefile
index f03d116..c9d372b 100644
--- a/Makefile
+++ b/Makefile
@@ -471,12 +471,10 @@ $(obj)u-boot.sb: $(obj)u-boot.bin $(obj)spl/u-boot-spl.bin
$(obj)u-boot.spr: $(obj)u-boot.img $(obj)spl/u-boot-spl.bin
$(obj)tools/mkimage -A $(ARCH) -T firmware -C none \
-a $(CONFIG_SPL_TEXT_BASE) -e $(CONFIG_SPL_TEXT_BASE) -n XLOADER \
- -d $(obj)spl/u-boot-spl.bin $(obj)spl/u-boot-spl.img
- tr "\000" "\377" < /dev/zero | dd ibs=1 count=$(CONFIG_SPL_PAD_TO) \
- of=$(obj)spl/u-boot-spl-pad.img 2>/dev/null
- dd if=$(obj)spl/u-boot-spl.img of=$(obj)spl/u-boot-spl-pad.img \
- conv=notrunc 2>/dev/null
- cat $(obj)spl/u-boot-spl-pad.img $(obj)u-boot.img > $@
+ -d $(obj)spl/u-boot-spl.bin $@
+ $(OBJCOPY) -I binary -O binary \
+ --pad-to=$(CONFIG_SPL_PAD_TO) --gap-fill=0xff $@
+ cat $(obj)u-boot.img >> $@
ifneq ($(CONFIG_TEGRA),)
$(obj)u-boot-nodtb-tegra.bin: $(obj)spl/u-boot-spl.bin $(obj)u-boot.bin
@@ -499,11 +497,9 @@ $(obj)u-boot-img.bin: $(obj)spl/u-boot-spl.bin $(obj)u-boot.img
# at the start padded up to the start of the SPL image. And then concat
# the SPL image to the end.
$(obj)u-boot-img-spl-at-end.bin: $(obj)spl/u-boot-spl.bin $(obj)u-boot.img
- tr "\000" "\377" < /dev/zero | dd ibs=1 count=$(CONFIG_UBOOT_PAD_TO) \
- of=$(obj)u-boot-pad.img 2>/dev/null
- dd if=$(obj)u-boot.img of=$(obj)u-boot-pad.img \
- conv=notrunc 2>/dev/null
- cat $(obj)u-boot-pad.img $(obj)spl/u-boot-spl.bin > $@
+ $(OBJCOPY) -I binary -O binary --pad-to=$(CONFIG_UBOOT_PAD_TO) \
+ --gap-fill=0xff $(obj)u-boot.img $@
+ cat $(obj)spl/u-boot-spl.bin >> $@
ifeq ($(CONFIG_SANDBOX),y)
GEN_UBOOT = \
--
1.8.3.2
^ permalink raw reply related
* [U-Boot] [PATCH] Makefile: fix broken pipe error for lcd4_lwmon5 board
From: Stefan Roese @ 2013-12-18 9:31 UTC (permalink / raw)
To: u-boot
In-Reply-To: <1387355538-29627-1-git-send-email-yamada.m@jp.panasonic.com>
Hi Masahiro,
On 18.12.2013 09:32, Masahiro Yamada wrote:
> Before this commit, a broken pipe error sometimes happened
> when building lcd4_lwmon5 board with Buildman.
>
> This commit re-writes build rules of
> u-boot.spr and u-boot-img-spl-at-end.bin
> more simply without using a pipe.
>
> Besides fixing a broken pipe error,
> this commit gives us other advantages:
>
> - Do not generate intermidiate files, spl/u-boot-spl.img
> and spl/u-boot-spl-pad.img for creating u-boot.spr
>
> - Do not generate an intermidiate file, u-boot-pad.img
> for creating u-boot-img-spl-at-end.bin
>
> Such intermidiate files were not deleted by "make clean" or "make mrpropr".
> Nor u-boot-pad.img was ignored by git.
>
> Signed-off-by: Masahiro Yamada <yamada.m@jp.panasonic.com>
This looks like a nice improvement. Thanks!
Acked-by: Stefan Roese <sr@denx.de>
Thanks,
Stefan
^ permalink raw reply
* [U-Boot] [PATCH] Makefile: fix broken pipe error for lcd4_lwmon5 board
From: Masahiro Yamada @ 2013-12-18 8:32 UTC (permalink / raw)
To: u-boot
Before this commit, a broken pipe error sometimes happened
when building lcd4_lwmon5 board with Buildman.
This commit re-writes build rules of
u-boot.spr and u-boot-img-spl-at-end.bin
more simply without using a pipe.
Besides fixing a broken pipe error,
this commit gives us other advantages:
- Do not generate intermidiate files, spl/u-boot-spl.img
and spl/u-boot-spl-pad.img for creating u-boot.spr
- Do not generate an intermidiate file, u-boot-pad.img
for creating u-boot-img-spl-at-end.bin
Such intermidiate files were not deleted by "make clean" or "make mrpropr".
Nor u-boot-pad.img was ignored by git.
Signed-off-by: Masahiro Yamada <yamada.m@jp.panasonic.com>
---
Hello Simon.
I noticed a broken pipe error when I was using Buildman.
The error happens here:
$(obj)u-boot-img-spl-at-end.bin: $(obj)spl/u-boot-spl.bin $(obj)u-boot.img
tr "\000" "\377" < /dev/zero | dd ibs=1 count=$(CONFIG_UBOOT_PAD_TO) \
of=$(obj)u-boot-pad.img 2>/dev/null
I cannot understand why this error happens on Buildman.
(I have never seen it on MAKEALL script.)
Does the same error happen on your machine too?
Do you have any idea why this error happen?
What I did is as follows:
$ git checkout master
$ git describe
v2014.01-rc2
$ git checkout -b cosmetic
Add many cosmetic commits. Do not change any source files.
(For example, changing README files)
I think about 20 commits are enough.
$ git branch --set-upstream-to=master
$ tool/buildman/buildman -b cosmetic lcd4_lwmon5
No section: 'make-flags'
Building 21 commits for 1 boards (1 thread, 8 jobs per thread)
Cloning repo for thread 0
14 7 0 /21 lcd4_lwmon5
$ tools/buildman/buildman -se -b cosmetic
No section: 'make-flags'
Summary of 21 commits for 1194 boards (8 threads, 1 job per thread)
01: Prepare v2014.01-rc2
powerpc: + lcd4_lwmon5
+tr: write error: Broken pipe
+tr: write error
02: cosmetic1
powerpc: lcd4_lwmon5
-tr: write error: Broken pipe
-tr: write error
03: cosmetic2
04: cosmetic3
05: cosmetic4
06: cosmetic5
07: cosmetic6
08: cosmetic7
09: cosmetic8
10: cosmetic9
11: cosmetic10
12: cosmetic11
13: cosmetic12
14: cosmetic13
15: cosmetic14
16: cosmetic15
powerpc: + lcd4_lwmon5
+tr: write error: Broken pipe
+tr: write error
17: cosmetic16
18: cosmetic17
19: cosmetic18
20: cosmetic19
21: cosmetic20
Here, a broken pipe error occurred at 01 and fixed at 02.
It happend again at 16.
But the result changes every time.
The error happens randomly.
Makefile | 19 ++++++++-----------
1 file changed, 8 insertions(+), 11 deletions(-)
diff --git a/Makefile b/Makefile
index f03d116..de5969c 100644
--- a/Makefile
+++ b/Makefile
@@ -471,12 +471,10 @@ $(obj)u-boot.sb: $(obj)u-boot.bin $(obj)spl/u-boot-spl.bin
$(obj)u-boot.spr: $(obj)u-boot.img $(obj)spl/u-boot-spl.bin
$(obj)tools/mkimage -A $(ARCH) -T firmware -C none \
-a $(CONFIG_SPL_TEXT_BASE) -e $(CONFIG_SPL_TEXT_BASE) -n XLOADER \
- -d $(obj)spl/u-boot-spl.bin $(obj)spl/u-boot-spl.img
- tr "\000" "\377" < /dev/zero | dd ibs=1 count=$(CONFIG_SPL_PAD_TO) \
- of=$(obj)spl/u-boot-spl-pad.img 2>/dev/null
- dd if=$(obj)spl/u-boot-spl.img of=$(obj)spl/u-boot-spl-pad.img \
- conv=notrunc 2>/dev/null
- cat $(obj)spl/u-boot-spl-pad.img $(obj)u-boot.img > $@
+ -d $(obj)spl/u-boot-spl.bin $@
+ $(OBJCOPY) -I binary -O binary \
+ --pad-to=$(CONFIG_SPL_PAD_TO) --gap-fill=0xff $@
+ cat $(obj)u-boot.img >> $@
ifneq ($(CONFIG_TEGRA),)
$(obj)u-boot-nodtb-tegra.bin: $(obj)spl/u-boot-spl.bin $(obj)u-boot.bin
@@ -499,11 +497,10 @@ $(obj)u-boot-img.bin: $(obj)spl/u-boot-spl.bin $(obj)u-boot.img
# at the start padded up to the start of the SPL image. And then concat
# the SPL image to the end.
$(obj)u-boot-img-spl-at-end.bin: $(obj)spl/u-boot-spl.bin $(obj)u-boot.img
- tr "\000" "\377" < /dev/zero | dd ibs=1 count=$(CONFIG_UBOOT_PAD_TO) \
- of=$(obj)u-boot-pad.img 2>/dev/null
- dd if=$(obj)u-boot.img of=$(obj)u-boot-pad.img \
- conv=notrunc 2>/dev/null
- cat $(obj)u-boot-pad.img $(obj)spl/u-boot-spl.bin > $@
+ cp $(obj)u-boot.img $@
+ $(OBJCOPY) -I binary -O binary --pad-to=$(CONFIG_UBOOT_PAD_TO) \
+ --gap-fill=0xff $(obj)u-boot.img $@
+ cat $(obj)spl/u-boot-spl.bin >> $@
ifeq ($(CONFIG_SANDBOX),y)
GEN_UBOOT = \
diff --git a/board/samsung/trats2/trats2.c b/board/samsung/trats2/trats2.c
index 147de17..be15357 100644
--- a/board/samsung/trats2/trats2.c
+++ b/board/samsung/trats2/trats2.c
@@ -195,9 +195,9 @@ int power_init_board(void)
#endif
pmic_init(I2C_7); /* I2C adapter 7 - bus name s3c24x0_7 */
pmic_init_max77686();
- pmic_init_max77693(I2C_9); /* I2C adapter 9 - bus name soft1 */
- power_muic_init(I2C_9); /* I2C adapter 9 - bus name soft1 */
- power_fg_init(I2C_8); /* I2C adapter 8 - bus name soft0 */
+ pmic_init_max77693(I2C_10); /* I2C adapter 10 - bus name soft1 */
+ power_muic_init(I2C_10); /* I2C adapter 10 - bus name soft1 */
+ power_fg_init(I2C_9); /* I2C adapter 9 - bus name soft0 */
power_bat_init(0);
p_chrg = pmic_get("MAX77693_PMIC");
--
1.8.3.2
^ permalink raw reply related
page: next (older) | prev (newer) | latest
- recent:[subjects (threaded)|topics (new)|topics (active)]
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox